@@ -2,5 +2,14 @@ from .data import html_map, html_list, html_table, wrap
 from .hyperlinks import a_or_span, a_or_p, a_or_button, hyperlink, breadcrumbs, url
 from .icons import icon, fa_icon
 from .text import markdown, elem_or_span, elem_or_div
-from .page import meta_properties, meta_headers, meta_og, meta_values, \
-    stylesheets, scripts, favicons, google_analytics, Head
+from .page import (
+    meta_properties,
+    meta_headers,
+    meta_og,
+    meta_values,
+    stylesheets,
+    scripts,
+    favicons,
+    google_analytics,
+    Head,
+)
