@@ -1,9 +1,11 @@
-import collections
+import collections.abc
 
-from ..core import Element
+from sidekick import lazy_singledispatch
+
+from ..core import Element, Text, Blob
 from ..html import html
 from ..tags import a, p, span, h, ul, li, input_, button
-from ..utils import escape, lazy_singledispatch
+from ..utils import escape
 from ..utils.role_dispatch import role_singledispatch
 
 
@@ -37,9 +39,9 @@ def a_or_button(*args, href=None, submit=False, reset=False, **kwargs):
     if href:
         return a(*args, href=href, **kwargs)
     elif submit:
-        return input_(type='submit', value=args[0], **kwargs)
+        return input_(type="submit", value=args[0], **kwargs)
     elif reset:
-        return input_(type='reset', value=args[0], **kwargs)
+        return input_(type="reset", value=args[0], **kwargs)
     else:
         return button(*args, **kwargs)
 
@@ -61,7 +63,7 @@ def hyperlink(obj, href=None, **attrs) -> Element:
             the link must be stored in the 'content' key:
 
             >>> hyperlink({'href': 'www.python.com', 'content': 'Python'})
-            <a href="www.python.com">Python</a>
+             h('a', {'href': 'www.python.com'}, 'Python')
 
         django model:
             It must define a get_absolute_url() method. This function uses
@@ -69,10 +71,10 @@ def hyperlink(obj, href=None, **attrs) -> Element:
 
             >>> from django.contrib.auth import get_user_model
             >>> user_model = get_user_model()
-            >>> hyperlink(user_model(first_name='Joe', username='joe123'))
+            >>> link = hyperlink(user_model(first_name='Joe', username='joe123'))
+            >>> print(link)
             <a href="/users/joe123">Joe</a>
 
-
     In order to support other types, use the lazy_singledispatch mechanism::
 
         @hyperlink.registerPlugin(MyFancyType)
@@ -88,8 +90,8 @@ def hyperlink(obj, href=None, **attrs) -> Element:
     """
 
     data = html(obj)
-    attrs['href'] = href or url(obj)
-    return h('a', attrs, data)
+    attrs["href"] = href or url(obj)
+    return h("a", attrs, data)
 
 
 @hyperlink.register(str)
@@ -97,27 +99,30 @@ def _hyperlink_str(data, href=None, **attrs):
     if href is None:
         data, href = split_link(data)
     if not href:
-        raise ValueError('string does not declare a target url')
-    attrs['href'] = href
-    return h('a', attrs, escape(data))
+        raise ValueError("string does not declare a target url")
+    attrs["href"] = href
+    return h("a", attrs, escape(data))
 
 
-@hyperlink.register(collections.Mapping)
+@hyperlink.register(collections.abc.Mapping)
 def _hyperlink_map(obj, **attrs):
-    content = obj['content']
-    if 'href' not in obj:
-        raise ValueError('mapping must define an href key.')
+    content = obj["content"]
+    if "href" not in obj:
+        raise ValueError("mapping must define an href key.")
     for k, v in obj.items():
-        if k != 'content':
+        if k != "content":
             attrs.setdefault(k, v)
-    return h('a', attrs, content)
+    return h("a", attrs, content)
 
 
-@hyperlink.register('django.db.models.Model')
+@hyperlink.register("django.db.models.Model")
 def _hyperlink_model(x, **attrs):
-    attrs['href'] = attrs.get('href') or x.get_absolute_url()
-    body = html(x)
-    return h('a', attrs, body)
+    attrs["href"] = attrs.get("href") or x.get_absolute_url()
+    try:
+        body = Blob(x.__html__())
+    except AttributeError:
+        body = Text(str(x))
+    return h("a", attrs, body)
 
 
 @role_singledispatch
@@ -125,11 +130,11 @@ def url(obj):
     """
     Returns a url for the given object.
     """
-    if hasattr(obj, '__url__'):
+    if hasattr(obj, "__url__"):
         return obj.__url__()
-    if hasattr(obj, 'get_absolute_url'):
+    if hasattr(obj, "get_absolute_url"):
         return obj.get_absolute_url()
-    raise TypeError(f'no methods registered for {type(obj).__class__}')
+    raise TypeError(f"no methods registered for {type(obj).__class__}")
 
 
 def split_link(name):
@@ -138,14 +143,14 @@ def split_link(name):
 
     If no link is found, the second value is None.
     """
-    if name.endswith('>'):
-        name, sep, link = name.partition('<')
+    if name.endswith(">"):
+        name, sep, link = name.partition("<")
         if sep:
             return name.rstrip(), link[:-1]
     return name, None
 
 
-def breadcrumbs(links, class_='breadcrumbs'):
+def breadcrumbs(links, class_="breadcrumbs"):
     """
     Component that Receives a list of links and return a breadcrumbs element.
     """
