@@ -3,9 +3,9 @@ import re
 from markupsafe import Markup
 from sidekick import import_later
 
-lxml_html = import_later('lxml.html')
-lxml_etree = import_later('lxml.etree')
-head_children = re.compile(r'^<(?:title|meta|script|style|link)')
+lxml_html = import_later("lxml.html")
+lxml_etree = import_later("lxml.etree")
+head_children = re.compile(r"^<(?:title|meta|script|style|link)")
 
 
 def render_pretty(source, raw=False):
@@ -19,10 +19,10 @@ def render_pretty(source, raw=False):
         source = source.render()
 
     root = lxml_html.fromstring(source)
-    pretty = lxml_etree.tostring(root, encoding='unicode', pretty_print=True)
+    pretty = lxml_etree.tostring(root, encoding="unicode", pretty_print=True)
 
     # lxml adds <head> and <html> tags if the root tag should be
-    if source.startswith('<head'):
+    if source.startswith("<head"):
         pretty = dedent(pretty[7:-8], 2)
     elif head_children.match(source):
         pretty = dedent(pretty[16:-18], 4)
@@ -34,4 +34,4 @@ def render_pretty(source, raw=False):
 
 
 def dedent(st, size):
-    return '\n'.join(line[size:] for line in st.splitlines())
+    return "\n".join(line[size:] for line in st.splitlines())
